@@ -39,17 +39,18 @@ def _batch_records_helper(
     assert min_common_dimensions >= 0
 
     if len(records) < 2:
-        return records, []
+        return Batch(records, TimestreamDimensions()), []
     
     indexes = [0] # indexes for all the records in the batch
     common_dimensions = records[0].dimensions
+    min_common_dimensions = min(min_common_dimensions, len(common_dimensions))
 
     for i in range(1, len(records)):
         if len(indexes) >= max_batch_size:
             break
 
         dimensions, shared = records[i].dimensions, {}
-        for k in dimensions.get_dimension_keys():
+        for k in common_dimensions.get_dimension_keys():
             if dimensions.get_dimension(k) == common_dimensions.get_dimension(k):
                 shared[k] = True
         
